@@ -124,8 +124,11 @@ fit_pamr <- function(x, y, error_fun, cv, nfold, threshold=NULL, ...,
                     if(slim){
                         model.cv$cv.objects <- NULL
                     }
-                    model.cv$error <- sapply(seq_along(model.cv$threshold), function(i)
-                        error_fun(model.cv$y, list(prediction=model.cv$yhat[[i]], probability=model.cv$probability[,,i])))
+                    model.cv$error <- sapply(seq_along(model.cv$threshold), function(i){
+                      prediction <- structure(list(prediction=model.cv$yhat[[i]], probability=model.cv$prob[,,i]),
+                                              class = "prediction")
+                      error_fun(model.cv$y, prediction)
+                    })
                 }
             } else {
                 if(!missing(cv) && !is_blank(cv))
